@@ -104,6 +104,7 @@ DTypeColor::Ptr ColorSeletorWidget::getSelectedColorInfo()
         CConfigSettings::getInstance()->setOption("LastSysColorTypeNo", m_colorInfo->colorID());
     } else if (!m_colorInfo->colorCode().isEmpty() ){
         CConfigSettings::getInstance()->setOption("LastUserColor", m_colorInfo->colorCode());
+        CConfigSettings::getInstance()->setOption("LastSysColorTypeNo", "");
     }
     return m_colorInfo;
 }
@@ -120,12 +121,15 @@ void ColorSeletorWidget::setSelectedColorByIndex(int index)
 
 void ColorSeletorWidget::setSelectedColorById(int colorId)
 {
-    //如果是用户自定义颜色则直接选第一个
-    if ((colorId > 8 || colorId < 0) && m_userColorBtn) {
+    //默认选择第一个
+    if( colorId < 0 ) {
         if (m_colorGroup->buttons().size() > 0) {
             m_colorGroup->buttons().at(0)->click();
         }
         return;
+    } else if ( colorId == 9 ) {
+        m_userColorBtn->click();
+        return;
     }
 
     //系统颜色则向后移一位
@@ -135,7 +139,7 @@ void ColorSeletorWidget::setSelectedColorById(int colorId)
         ++colorId;
     }
     if (m_colorGroup->buttons().size() > 0) {
-        m_colorGroup->buttons().at(colorId)->click();
+         m_colorGroup->buttons().at(colorId)->click();
     }
 }
 
