@@ -35,7 +35,7 @@ CTitleWidget::CTitleWidget(QWidget *parent)
 {
     m_sidebarIcon = new DIconButton(this);
     m_sidebarIcon->setFixedSize(QSize(36, 36));
-    m_sidebarIcon->setIconSize(QSize(16, 16));
+    m_sidebarIcon->setIconSize(QSize(19, 15));
     connect(m_sidebarIcon, &DIconButton::clicked, this, &CTitleWidget::slotSidebarIconClicked);
 
     m_buttonBox = new CButtonBox(this);
@@ -107,6 +107,8 @@ CTitleWidget::CTitleWidget(QWidget *parent)
     m_searchEdit->lineEdit()->installEventFilter(this);
     m_searchEdit->setPlaceHolder(tr("Search events and festivals"));
     m_searchEdit->setPlaceholderText(tr("Search events and festivals"));
+
+    m_strPlaceHolder = m_searchEdit->placeholderText();
     connect(m_searchEdit, &DSearchEdit::searchAborted, [&] {
         //搜索框关闭按钮，清空数据
         slotSearchEditFocusChanged(false);
@@ -145,8 +147,8 @@ CTitleWidget::CTitleWidget(QWidget *parent)
     layout->addWidget(leftWidget);
     layout->addWidget(m_newScheduleBtn, Qt::AlignRight);
     this->setLayout(layout);
-    //设置焦点代理为buttonBox
-    setFocusProxy(m_buttonBox);
+    //设置焦点代理为m_sidebarIcon
+    setFocusProxy(m_sidebarIcon);
 }
 
 void CTitleWidget::setShowState(CTitleWidget::Title_State state)
@@ -159,6 +161,7 @@ void CTitleWidget::setSidebarStatus(bool status)
 {
     m_sidebarstatus = status;
     updateSidebarIconStatus();
+    m_clickShowLeft = status;
     emit signalSidebarStatusChange(m_sidebarstatus&m_sidebarCanDisplay);
     //将状态保存在配置文件中
     gSetting->setUserSidebarStatus(status);
@@ -167,7 +170,6 @@ void CTitleWidget::setSidebarStatus(bool status)
 void CTitleWidget::setSidebarCanDisplay(bool can)
 {
     m_sidebarCanDisplay = can;
-    emit signalSidebarStatusChange(m_sidebarstatus&m_sidebarCanDisplay);
 }
 
 bool CTitleWidget::getSidevarStatus()
@@ -210,7 +212,6 @@ void CTitleWidget::stateUpdate()
         m_buttonBox->show();
         m_searchPush->hide();
         normalStateUpdateSearchEditWidth();
-        setFocusProxy(m_buttonBox);
     } break;
     }
 }
@@ -221,8 +222,9 @@ void CTitleWidget::miniStateShowSearchEdit()
     m_searchPush->hide();
     m_searchEdit->setMaximumWidth(width());
     m_searchEdit->show();
-    //取消焦点代理
-    setFocusProxy(nullptr);
+  
+    m_searchEdit->setPlaceHolder(m_strPlaceHolder);
+    m_searchEdit->setPlaceholderText(m_strPlaceHolder);
 }
 
 void CTitleWidget::normalStateUpdateSearchEditWidth()
@@ -250,6 +252,37 @@ void CTitleWidget::resizeEvent(QResizeEvent *event)
     if (m_showState == Title_State_Normal) {
         normalStateUpdateSearchEditWidth();
     }
+    QString str  = m_strPlaceHolder;
+    QFontMetrics fontMetrice(m_searchEdit->font());
+    if(fontMetrice.width(str) > (m_searchEdit->width()-30) && m_clickShowLeft == false && !m_buttonBox->isHidden()) {
+        str = fontMetrice.elidedText(str,Qt::ElideRight,m_searchEdit->width()-30);
+        m_searchEdit->setPlaceHolder(str);
+        m_searchEdit->setPlaceholderText(str);
+    } else {
+        m_searchEdit->setPlaceHolder(m_strPlaceHolder);
+        m_searchEdit->setPlaceholderText(m_strPlaceHolder);
+        m_clickShowLeft = false;
+    }
+}
+
+void CTitleWidget::changeEvent(QEvent *e) {
+    QWidget::changeEvent(e);
+    if(e->type() == QEvent::FontChange) {
+        updateSearchEditPlaceHolder();
+    }
+}
+
+void  CTitleWidget::updateSearchEditPlaceHolder() {
+    QString str  = m_strPlaceHolder;
+    QFontMetrics fontMetrice(m_searchEdit->font());
+    if(fontMetrice.width(str) > (m_searchEdit->width()-30)) {
+        str = fontMetrice.elidedText(str,Qt::ElideRight,m_searchEdit->width()-30);
+        m_searchEdit->setPlaceHolder(str);
+        m_searchEdit->setPlaceholderText(str);
+    } else {
+        m_searchEdit->setPlaceHolder(m_strPlaceHolder);
+        m_searchEdit->setPlaceholderText(m_strPlaceHolder);
+    }
 }
 
 bool CTitleWidget::eventFilter(QObject *o, QEvent *e)
@@ -283,6 +316,7 @@ void CTitleWidget::slotShowSearchEdit()
 {
     miniStateShowSearchEdit();
     m_searchEdit->setFocus();
+
 }
 
 void CTitleWidget::slotSearchEditFocusChanged(bool onFocus)
@@ -296,7 +330,6 @@ void CTitleWidget::slotSearchEditFocusChanged(bool onFocus)
         m_buttonBox->show();
         m_searchEdit->hide();
         m_searchPush->show();
-        setFocusProxy(m_buttonBox);
     }
 }
 
