@@ -39,9 +39,9 @@
 #include <QKeyEvent>
 #include <QPainter>
 #include <QBitmap>
+#include <QTimer>
 
 const int  dialog_width = 468;      //对话框宽度
-
 DGUI_USE_NAMESPACE
 CScheduleDlg::CScheduleDlg(int type, QWidget *parent, const bool isAllDay)
     : DCalendarDDialog(parent)
@@ -71,6 +71,10 @@ CScheduleDlg::CScheduleDlg(int type, QWidget *parent, const bool isAllDay)
         m_titleLabel->setText(tr("Edit Event"));
     }
     setFixedSize(dialog_width, 561);
+    if(!gAccountManager->getIsSupportUid()) {
+        setFixedSize(dialog_width, 561-36);
+    }
+
     //焦点设置到输入框
     m_textEdit->setFocus();
 }
@@ -192,15 +196,21 @@ bool CScheduleDlg::selectScheduleType()
         type->setTypeID("0");
         type->setDisplayName(m_typeComBox->lineEdit()->text());
         type->setTypeColor(*m_colorSeletorWideget->getSelectedColorInfo().data());
-        //创建日程类型，等待回调
-        m_accountItem->createJobType(type, [&](CallMessge call) {
-            if (call.code == 0) {
-                //返回值为日程类型id
-                createSchedule(call.msg.toString());
-            }
-            //关闭本弹窗
-            this->close();
-        });
+        if(m_bCanCreateType) {
+            m_bCanCreateType = false;
+            //创建日程类型，等待回调
+            m_accountItem->createJobType(type, [&](CallMessge call) {
+                if (call.code == 0) {
+                    //返回值为日程类型id
+                    createSchedule(call.msg.toString());
+                } else {
+                    m_bCanCreateType = true;
+                }
+                //关闭本弹窗
+                this->close();
+            });
+        }
+
     } else if (m_typeComBox->currentIndex() >= 0) {
         //选择已有日程，直接创建日程
         return createSchedule(m_typeComBox->getCurrentJobTypeNo());
@@ -246,7 +256,7 @@ bool CScheduleDlg::createSchedule(const QString &scheduleTypeId)
     if (m_textEdit->toPlainText().isEmpty()) {
         schedule->setSummary(m_textEdit->placeholderText());
     } else {
-        schedule->setSummary(m_textEdit->toPlainText());
+        schedule->setSummary(m_textEdit->toPlainText().trimmed());
     }
 
     if (schedule->summary().isEmpty()) {
@@ -293,7 +303,7 @@ bool CScheduleDlg::createSchedule(const QString &scheduleTypeId)
         if (m_endrepeattimes->text().isEmpty()) {
             return false;
         }
-        schedule->recurrence()->setDuration(m_endrepeattimes->text().toInt());
+        schedule->recurrence()->setDuration(m_endrepeattimes->text().toInt() + 1 );
 
     } else if (m_endrepeatCombox->currentIndex() == 2) {
         //结束与日期
@@ -408,7 +418,7 @@ void CScheduleDlg::slotBtClick(int buttonIndex, const QString &buttonName)
         //确定
         //自动化测试会出现短时间内按钮click2次的情况。添加第一次触发后将保存按钮置灰的设置。
         //若保存按钮不启用则不处理
-        if (getButton(1)->isEnabled()) {
+        if (getButton(1)->isEnabled()  && !this->isHidden()) {
             m_setAccept = clickOkBtn();
             //若新建或编辑成功则将保存按钮置灰
             getButton(1)->setEnabled(!m_setAccept);
@@ -451,7 +461,9 @@ void CScheduleDlg::slotTextChange()
         return;
     }
 
-    m_context = m_textEdit->toPlainText();
+    setOkBtnEnabled();
+
+    m_context = m_textEdit->toPlainText().trimmed();
 }
 
 void CScheduleDlg::slotendrepeatTextchange()
@@ -828,6 +840,9 @@ void CScheduleDlg::initUI()
         widget->setLayout(hlayout);
         widget->setFixedHeight(item_Fixed_Height);
         maintlayout->addWidget(widget);
+        if(!gAccountManager->getIsSupportUid()) {
+            widget->hide();
+        }
     }
 
     //类型
@@ -1328,7 +1343,7 @@ void CScheduleDlg::initRmindRpeatUI()
     } else {
         //结束与次数
         m_endrepeatCombox->setCurrentIndex(1);
-        m_endrepeattimes->setText(QString::number(m_scheduleDataInfo->recurrence()->duration()));
+        m_endrepeattimes->setText(QString::number(m_scheduleDataInfo->recurrence()->duration()-1));
     }
     sloteRpeatactivated(m_endrepeatCombox->currentIndex());
 }
@@ -1499,7 +1514,16 @@ void CScheduleDlg::resetColor(const AccountItem::Ptr &account)
         //如果是int型表示为旧颜色编号
         colorNum = colorId.toInt();
     } else {
-        colorNum = GTypeColor.keys().indexOf(colorId.toString());
+        QString &&colorIdStr = colorId.toString();
+        //如果都为空表示为初始状态，则选中第一个
+        if(colorName.isEmpty() && colorIdStr.isEmpty()){
+            colorNum = -1;
+        } else if (!colorIdStr.isEmpty()) {
+            //如果颜色id不为空则表示颜色为内置颜色
+            colorNum = GTypeColor.keys().indexOf(colorIdStr);
+        } else {
+            colorNum = 9;
+        }
     }
     m_colorSeletorWideget->setSelectedColorById(colorNum);
 }
@@ -1514,6 +1538,10 @@ void CScheduleDlg::resize()
     if (m_colorSeletorWideget->isVisible()) {
         h += 18 + 10;
     }
+    if(!gAccountManager->getIsSupportUid()) {
+        h -=36;
+    }
+
     //573: 默认界面高度, h: 新增控件高度
     setFixedSize(dialog_width, 573 + h);
 }
@@ -1540,4 +1568,11 @@ void CScheduleDlg::setOkBtnEnabled()
         //日期  //永不
         m_OkBt->setEnabled(true);
     }
+
+    if(!m_textEdit->toPlainText().isEmpty() && m_textEdit->toPlainText().trimmed().isEmpty()) {
+        m_OkBt->setEnabled(false);
+    }
+    else {
+        m_OkBt->setEnabled(true);
+    }
 }
