@@ -198,10 +198,13 @@ void CSettingDialog::initView()
         }
     }
 
-    //暂时屏蔽云同步部分
-//    if (DSysInfo::uosEditionType() == DSysInfo::UosCommunity) {
+    //如果不支持则屏蔽
+    if (!gAccountManager->getIsSupportUid()) {
         setGroupVisible("setting_account", false);
-//    }
+        setGroupVisible("setting_base.acccount_items", false);
+    }
+
+
     //未登录uos帐号时，移除部分选项
     if (!gUosAccountItem) {
         setGroupVisible("setting_account.account_sync_items", false);
@@ -271,6 +274,17 @@ void CSettingDialog::initConnect()
     //TODO:更新union帐户的的同步频率
     connect(m_syncFreqComboBox, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &CSettingDialog::slotSetUosSyncFreq);
     connect(m_syncBtn, &QPushButton::clicked, this, &CSettingDialog::slotUosManualSync);
+    connect(m_ptrNetworkState,&DOANetWorkDBus::sign_NetWorkChange,this,&CSettingDialog::slotNetworkStateChange);
+}
+
+void CSettingDialog::slotNetworkStateChange(DOANetWorkDBus::NetWorkState state) {
+    if(DOANetWorkDBus::NetWorkState::Active == state) {
+        if (!gUosAccountItem.isNull() && (gUosAccountItem->isCanSyncSetting() || gUosAccountItem->isCanSyncShedule())) {
+            m_syncBtn->setEnabled(true);
+        }
+    } else if(DOANetWorkDBus::NetWorkState::Disconnect == state) {
+        m_syncBtn->setEnabled(false);
+    }
 }
 
 void CSettingDialog::initData()
@@ -360,11 +374,13 @@ void CSettingDialog::initSyncFreqWidget()
     m_syncFreqComboBox->addItem(tr("30 mins"),  DAccount::SyncFreq_30Mins);
     m_syncFreqComboBox->addItem(tr("1 hour"),   DAccount::SyncFreq_1hour);
     m_syncFreqComboBox->addItem(tr("24 hours"), DAccount::SyncFreq_24hour);
+    m_syncFreqComboBox->setCurrentIndex(1); // 默认15分钟
 }
 
 void CSettingDialog::initManualSyncButton()
 {
     m_manualSyncWidget = new QWidget;
+    m_ptrNetworkState = new DOANetWorkDBus(this);
     m_manualSyncWidget->setObjectName("ManualSyncWidget");
     m_syncBtn = new QPushButton(m_manualSyncWidget);
     m_syncBtn->setFixedSize(266, 36);
@@ -437,6 +453,7 @@ void CSettingDialog::slotAccountCurrentChanged(int index)
 {
     if (m_scheduleTypeWidget) {
         m_scheduleTypeWidget->updateCalendarAccount(m_accountComboBox->itemData(index).toString());
+        setTypeEnable(index);
     }
 }
 
@@ -477,7 +494,7 @@ void CSettingDialog::slotSyncTagButtonUpdate()
     m_radiobuttonAccountSetting->setEnabled(gUosAccountItem->isEnableForUosAccount());
 }
 
-void CSettingDialog::slotSyncAccountStateUpdate(bool)
+void CSettingDialog::slotSyncAccountStateUpdate(bool status)
 {
     if (!gUosAccountItem)
         return;
@@ -495,6 +512,9 @@ void CSettingDialog::slotSyncAccountStateUpdate(bool)
         state = state & ~DAccount::Account_Calendar;
 
     gUosAccountItem->setAccountState(state);
+    if(status) {
+        slotUosManualSync();
+    }
 }
 
 void CSettingDialog::slotLastSyncTimeUpdate(const QString &datetime)
@@ -531,7 +551,10 @@ void CSettingDialog::slotAccountStateChange()
             m_syncFreqComboBox->setEnabled(false);
         }
     }
-
+    if (m_accountComboBox && m_typeAddBtn)
+    {
+        setTypeEnable(m_accountComboBox->currentIndex());
+    }
 }
 
 void CSettingDialog::setFirstDayofWeek(int value)
@@ -578,9 +601,28 @@ void CSettingDialog::accountUpdate()
     if (m_accountComboBox->currentIndex() < 0)
         m_accountComboBox->setCurrentIndex(0);
     m_accountComboBox->blockSignals(false);
+
+    m_syncFreqComboBox->setCurrentIndex(1);  //每次登录的时候 默认15分钟
     slotAccountCurrentChanged(m_accountComboBox->currentIndex());
 }
 
+void CSettingDialog::setTypeEnable(int index)
+{
+    if (!gUosAccountItem) return;
+
+    QString accountId = m_accountComboBox->itemData(index).toString();
+
+    AccountItem::Ptr account = gAccountManager->getAccountItemByAccountId(accountId);
+
+    if (account->getAccount()->accountType() == DAccount::Account_Local || gUosAccountItem->isCanSyncShedule()) {
+        m_typeAddBtn->setEnabled(true);
+        m_scheduleTypeWidget->setItemEnabled(true);
+    } else {
+        m_typeAddBtn->setEnabled(false);
+        m_scheduleTypeWidget->setItemEnabled(false);
+    }
+}
+
 QPair<QWidget *, QWidget *> CSettingDialog::createFirstDayofWeekWidget(QObject *obj)
 {
     auto option = qobject_cast<DTK_CORE_NAMESPACE::DSettingsOption *>(obj);
