@@ -77,6 +77,13 @@ bool CScheduleOperation::changeSchedule(const DSchedule::Ptr &newInfo, const DSc
 
     if (newInfo->getRRuleType() == DSchedule::RRule_None && newInfo->getRRuleType() == oldInfo->getRRuleType()) {
         //如果为普通日程且没有修改重复类型则更新日程
+        if(newInfo->allDay() != oldInfo->allDay()) {
+            if(newInfo->allDay()) {
+                newInfo->setAlarmType(DSchedule::AlarmType::Alarm_15Hour_Front);
+            } else {
+                newInfo->setAlarmType(DSchedule::AlarmType::Alarm_15Min_Front);
+            }
+        }
         m_accountItem->updateSchedule(newInfo);
         _result = true;
     } else {
@@ -439,7 +446,9 @@ bool CScheduleOperation::scheduleIsInvariant(const DSchedule::Ptr &schedule)
         DOANetWorkDBus netManger;
         //网络判断
         //如果uid日历同步关闭则日程不可修改
-        if (netManger.getNetWorkState() != DOANetWorkDBus::Active || !account->accountState().testFlag(DAccount::Account_Open)) {
+        if (netManger.getNetWorkState() != DOANetWorkDBus::Active
+                || !account->accountState().testFlag(DAccount::Account_Open)
+                || !account->accountState().testFlag(DAccount::Account_Calendar)) {
             return true;
         }
     }
