@@ -67,7 +67,7 @@ CGraphicsView::CGraphicsView(QWidget *parent, ViewPosition Type)
     connect(this->verticalScrollBar(), &QScrollBar::sliderPressed, this, &CGraphicsView::slotScrollBar);
 
     //如果为周视图
-    if (m_viewType == 0) {
+    if (m_viewPos == WeekPos) {
         //设置显示右下角圆角
         setShowRadius(false, true);
     }
@@ -113,19 +113,17 @@ void CGraphicsView::setTheMe(int type)
 
 void CGraphicsView::slotCreate(const QDateTime &date)
 {
-    emit signalViewtransparentFrame(1);
     CScheduleDlg dlg(1, this);
     dlg.setDate(date);
 
     if (dlg.exec() == DDialog::Accepted) {
         emit signalsUpdateSchedule();
     }
-    emit signalViewtransparentFrame(0);
 }
 
 bool CGraphicsView::MeetCreationConditions(const QDateTime &date)
 {
-    return qAbs(date.daysTo(m_PressDate) < 7);
+    return qAbs(date.daysTo(m_PressDate)) < 7;
 }
 
 void CGraphicsView::updateHeight()
@@ -140,28 +138,15 @@ void CGraphicsView::setCurrentDate(const QDateTime &currentDate)
     scrollBarValueChangedSlot();
 }
 
-void CGraphicsView::setInfo(const QVector<ScheduleDataInfo> &info)
+void CGraphicsView::setInfo(const DSchedule::List &info)
 {
     m_scheduleInfo = info;
 }
 
-bool MScheduleTimeThan(const ScheduleDataInfo &s1, const ScheduleDataInfo &s2)
-{
-    if (s1.getBeginDateTime().date().daysTo(s1.getEndDateTime().date()) == s2.getBeginDateTime().date().daysTo(s2.getEndDateTime().date())) {
-        if (s1.getBeginDateTime() == s2.getBeginDateTime()) {
-            return s1.getBeginDateTime().secsTo(s1.getEndDateTime()) > s2.getBeginDateTime().secsTo(s2.getEndDateTime());
-        } else {
-            return s1.getBeginDateTime() < s2.getBeginDateTime();
-        }
-    } else {
-        return s1.getBeginDateTime().date().daysTo(s1.getEndDateTime().date()) > s2.getBeginDateTime().date().daysTo(s2.getEndDateTime().date());
-    }
-}
-
-void CGraphicsView::upDateInfoShow(const CGraphicsView::DragStatus &status, const ScheduleDataInfo &info)
+void CGraphicsView::upDateInfoShow(const CGraphicsView::DragStatus &status, const DSchedule::Ptr &info)
 {
     clearSchedule();
-    QVector<ScheduleDataInfo> vListData;
+    DSchedule::List vListData;
     vListData = m_scheduleInfo;
 
     switch (status) {
@@ -181,29 +166,29 @@ void CGraphicsView::upDateInfoShow(const CGraphicsView::DragStatus &status, cons
         vListData.append(info);
         break;
     }
-    QMap<QDate, QVector<ScheduleDataInfo>> m_InfoMap;
+    QMap<QDate, DSchedule::List> m_InfoMap;
     QDate currentDate;
     qint64 count = m_beginDate.daysTo(m_endDate);
     qint64 beginoffset = 0, endoffset = 0;
-    QVector<ScheduleDataInfo> currentInfo;
+    DSchedule::List currentInfo;
 
     for (int i = 0; i <= count; ++i) {
         currentDate = m_beginDate.addDays(i);
         currentInfo.clear();
 
         for (int j = 0; j < vListData.size(); ++j) {
-            beginoffset = vListData.at(j).getBeginDateTime().date().daysTo(currentDate);
-            endoffset = currentDate.daysTo(vListData.at(j).getEndDateTime().date());
+            beginoffset = vListData.at(j)->dtStart().date().daysTo(currentDate);
+            endoffset = currentDate.daysTo(vListData.at(j)->dtEnd().date());
 
             if (beginoffset < 0 || endoffset < 0) {
                 continue;
             }
-            if (vListData.at(j).getEndDateTime().date() == currentDate && vListData.at(j).getBeginDateTime().daysTo(vListData.at(j).getEndDateTime()) > 0 && vListData.at(j).getEndDateTime().time() == QTime(0, 0, 0)) {
+            if (vListData.at(j)->dtEnd().date() == currentDate && vListData.at(j)->dtStart().daysTo(vListData.at(j)->dtEnd()) > 0 && vListData.at(j)->dtEnd().time() == QTime(0, 0, 0)) {
                 continue;
             }
             currentInfo.append(vListData.at(j));
         }
-        std::sort(currentInfo.begin(), currentInfo.end(), MScheduleTimeThan);
+        std::sort(currentInfo.begin(), currentInfo.end());
         if (currentInfo.size() > 0) {
             m_InfoMap[currentDate] = currentInfo;
             QList<ScheduleclassificationInfo> info;
@@ -225,9 +210,10 @@ void CGraphicsView::upDateInfoShow(const CGraphicsView::DragStatus &status, cons
                             qWarning() << "week view create error,tNum -2 :" << index;
                             index = 1;
                         }
-                        ScheduleDataInfo tdetaliinfo = info.at(m).vData.at(index);
-                        tdetaliinfo.setTitleName("...");
-                        tdetaliinfo.setType(3);
+                        DSchedule::Ptr tdetaliinfo(info.at(m).vData.at(index)->clone());
+                        tdetaliinfo->setSummary("1");
+                        //如果为"..."则设置类型为other，在获取颜色时会对其进行判断
+                        tdetaliinfo->setScheduleTypeID("other");
                         addScheduleItem(tdetaliinfo, currentDate, tNum, tNum, 1,
                                         m_viewType, m_sMaxNum);
                     } else {
@@ -262,28 +248,29 @@ void CGraphicsView::ShowSchedule(DragInfoItem *infoitem)
     DragInfoGraphicsView::ShowSchedule(infoitem);
 }
 
-void CGraphicsView::MoveInfoProcess(ScheduleDataInfo &info, const QPointF &pos)
+void CGraphicsView::MoveInfoProcess(DSchedule::Ptr &info, const QPointF &pos)
 {
     Q_UNUSED(pos);
 
-    if (!info.getAllDay()) {
+    if (!info->allDay()) {
         qint64 offset = m_PressDate.secsTo(m_MoveDate);
-        info.getBeginDateTime() = info.getBeginDateTime().addSecs(offset);
-        info.getEndDateTime() = info.getEndDateTime().addSecs(offset);
+        info->setDtStart(info->dtStart().addSecs(offset));
+        info->setDtEnd(info->dtEnd().addSecs(offset));
     } else {
-        info.setAllDay(false);
-        info.setRemindData(RemindData());
-        info.getBeginDateTime() = m_MoveDate;
-        info.getEndDateTime() = m_MoveDate.addSecs(3600);
+        info->setAllDay(false);
+        //提醒规则
+        info->setRRuleType(DSchedule::RRule_None);
+        info->setDtStart(m_MoveDate);
+        info->setDtEnd(m_MoveDate.addSecs(3600));
     }
     upDateInfoShow(ChangeWhole, info);
 }
 
-void CGraphicsView::addScheduleItem(const ScheduleDataInfo &info, QDate date, int index, int totalNum, int type, int viewtype, int maxnum)
+void CGraphicsView::addScheduleItem(const DSchedule::Ptr &info, QDate date, int index, int totalNum, int type, int viewtype, int maxnum)
 {
     CScheduleItem *item = new CScheduleItem(
-        m_coorManage->getDrawRegion(date, info.getBeginDateTime(),
-                                    info.getEndDateTime(), index, totalNum, maxnum,
+        m_coorManage->getDrawRegion(date, info->dtStart(),
+                                    info->dtEnd(), index, totalNum, maxnum,
                                     viewtype),
         nullptr, type);
     if (type == 1) {
@@ -298,10 +285,10 @@ void CGraphicsView::addScheduleItem(const ScheduleDataInfo &info, QDate date, in
  * @brief CGraphicsView::setSelectSearchSchedule        设置搜索选中日程
  * @param info
  */
-void CGraphicsView::setSelectSearchSchedule(const ScheduleDataInfo &info)
+void CGraphicsView::setSelectSearchSchedule(const DSchedule::Ptr &info)
 {
     DragInfoGraphicsView::setSelectSearchSchedule(info);
-    setTime(info.getBeginDateTime().time());
+    setTime(info->dtStart().time());
     for (int i = 0; i < m_vScheduleItem.size(); ++i) {
         if (m_vScheduleItem.at(i)->getType() == 1)
             continue;
@@ -325,19 +312,19 @@ void CGraphicsView::clearSchedule()
     m_updateDflag = true;
 }
 
-void CGraphicsView::scheduleClassificationType(QVector<ScheduleDataInfo> &scheduleInfolist, QList<ScheduleclassificationInfo> &info)
+void CGraphicsView::scheduleClassificationType(DSchedule::List &scheduleInfolist, QList<ScheduleclassificationInfo> &info)
 {
-    QVector<ScheduleDataInfo> schedulelist = scheduleInfolist;
+    DSchedule::List schedulelist = scheduleInfolist;
     if (schedulelist.isEmpty())
         return;
 
     info.clear();
-    std::sort(schedulelist.begin(), schedulelist.end(), MScheduleTimeThan);
+    std::sort(schedulelist.begin(), schedulelist.end());
     QVector<int> containIndex;
 
     for (int k = 0; k < schedulelist.count(); k++) {
-        QDateTime endTime = schedulelist.at(k).getEndDateTime();
-        QDateTime begTime = schedulelist.at(k).getBeginDateTime();
+        QDateTime endTime = schedulelist.at(k)->dtEnd();
+        QDateTime begTime = schedulelist.at(k)->dtStart();
 
         if (begTime.date().daysTo(endTime.date()) == 0 && begTime.time().secsTo(endTime.time()) < m_minTime) {
             endTime = begTime.addSecs(m_minTime);
@@ -348,13 +335,13 @@ void CGraphicsView::scheduleClassificationType(QVector<ScheduleDataInfo> &schedu
         containIndex.clear();
 
         for (int i = 0; i < info.count(); i++) {
-            if ((schedulelist.at(k).getBeginDateTime() >= info.at(i).begindate && schedulelist.at(k).getBeginDateTime() <= info.at(i).enddate) || (endTime >= info.at(i).begindate && endTime <= info.at(i).enddate)) {
+            if ((schedulelist.at(k)->dtStart() >= info.at(i).begindate && schedulelist.at(k)->dtStart() <= info.at(i).enddate) || (endTime >= info.at(i).begindate && endTime <= info.at(i).enddate)) {
                 containIndex.append(i);
             }
         }
         if (containIndex.count() == 0) {
             ScheduleclassificationInfo firstschedule;
-            firstschedule.begindate = schedulelist.at(k).getBeginDateTime();
+            firstschedule.begindate = schedulelist.at(k)->dtStart();
             firstschedule.enddate = endTime;
             firstschedule.vData.append(schedulelist.at(k));
             info.append(firstschedule);
@@ -373,8 +360,8 @@ void CGraphicsView::scheduleClassificationType(QVector<ScheduleDataInfo> &schedu
             for (int i = containIndex.count() - 1; i > 0; --i) {
                 info.removeAt(containIndex.at(i));
             }
-            if (schedulelist.at(k).getBeginDateTime() < scheduleInfo.begindate)
-                scheduleInfo.begindate = schedulelist.at(k).getBeginDateTime();
+            if (schedulelist.at(k)->dtStart() < scheduleInfo.begindate)
+                scheduleInfo.begindate = schedulelist.at(k)->dtStart();
             if (endTime > scheduleInfo.enddate)
                 scheduleInfo.enddate = endTime;
             scheduleInfo.vData.append(schedulelist.at(k));
@@ -390,26 +377,23 @@ void CGraphicsView::mouseDoubleClickEvent(QMouseEvent *event)
 
     if (item == nullptr) {
         QPointF scenePoss = mapToScene(event->pos());
-        emit signalViewtransparentFrame(1);
         CScheduleDlg dlg(1, this);
         QDateTime tDatatime = m_coorManage->getDate(scenePoss);
         dlg.setDate(tDatatime);
         if (dlg.exec() == DDialog::Accepted) {
             emit signalsUpdateSchedule();
         }
-        emit signalViewtransparentFrame(0);
         return;
     }
     if (item->getType() == 1) {
         emit signalsCurrentScheduleDate(item->getDate());
         return;
     }
-    emit signalViewtransparentFrame(1);
     m_updateDflag = false;
+    //TODO: item->getData()中的scheduleType为""，不是正常日程，有崩溃风险，待分析解决
     CMyScheduleView dlg(item->getData(), this);
     connect(&dlg, &CMyScheduleView::signalsEditorDelete, this, &CGraphicsView::slotDoubleEvent);
     dlg.exec();
-    emit signalViewtransparentFrame(0);
     disconnect(&dlg, &CMyScheduleView::signalsEditorDelete, this, &CGraphicsView::slotDoubleEvent);
 }
 
@@ -426,13 +410,16 @@ void CGraphicsView::mousePressEvent(QMouseEvent *event)
 
 void CGraphicsView::mouseMoveEvent(QMouseEvent *event)
 {
-    CScheduleItem *item = dynamic_cast<CScheduleItem *>(itemAt(event->pos()));
+    if (m_DragStatus == NONE) {
+        CScheduleItem *item = dynamic_cast<CScheduleItem *>(itemAt(event->pos()));
 
-    if (item != nullptr && item->getType() == 1) {
-        setCursor(Qt::ArrowCursor);
-        DGraphicsView::mouseMoveEvent(event);
-        return;
+        if (item != nullptr && item->getType() == 1) {
+            setCursor(Qt::ArrowCursor);
+            DGraphicsView::mouseMoveEvent(event);
+            return;
+        }
     }
+
     DragInfoGraphicsView::mouseMoveEvent(event);
 }
 void CGraphicsView::slotDoubleEvent(int type)
@@ -449,7 +436,6 @@ void CGraphicsView::slotScrollBar()
 
 void CGraphicsView::slotUpdateScene()
 {
-    pressScheduleInit();
     this->scene()->update();
 }
 
@@ -592,28 +578,30 @@ CGraphicsView::PosInItem CGraphicsView::getPosInItem(const QPoint &p, const QRec
     return MIDDLE;
 }
 
-ScheduleDataInfo CGraphicsView::getScheduleInfo(const QDateTime &beginDate, const QDateTime &endDate)
+DSchedule::Ptr CGraphicsView::getScheduleInfo(const QDateTime &beginDate, const QDateTime &endDate)
 {
-    ScheduleDataInfo info;
+    DSchedule::Ptr info(new DSchedule);
     if (beginDate.secsTo(endDate) > 0) {
-        info.getBeginDateTime() = beginDate;
+        info->setDtStart(beginDate);
 
         if (beginDate.secsTo(endDate) < DDECalendar::ThirtyMinutesWithSec) {
-            info.getEndDateTime() = beginDate.addSecs(DDECalendar::ThirtyMinutesWithSec);
+            info->setDtEnd(beginDate.addSecs(DDECalendar::ThirtyMinutesWithSec));
         } else {
-            info.getEndDateTime() = endDate;
+            info->setDtEnd(endDate);
         }
     } else {
         if (endDate.secsTo(beginDate) < DDECalendar::ThirtyMinutesWithSec) {
-            info.getBeginDateTime() = beginDate.addSecs(-DDECalendar::ThirtyMinutesWithSec);
+            info->setDtStart(beginDate.addSecs(-DDECalendar::ThirtyMinutesWithSec));
         } else {
-            info.getBeginDateTime() = endDate;
+            info->setDtStart(endDate);
         }
-        info.getEndDateTime() = beginDate;
+        info->setDtEnd(beginDate);
     }
-    info.setTitleName(tr("New Event"));
-    info.setAllDay(false);
-    info.setRemindData(RemindData(1, QTime(9, 0)));
+    info->setSummary(tr("New Event"));
+    info->setAllDay(false);
+    //设置默认日程类型为工作
+    info->setScheduleTypeID("107c369e-b13a-4d45-9ff3-de4eb3c0475b");
+    info->setAlarmType(DSchedule::Alarm_15Min_Front);
     return info;
 }
 
