@@ -138,7 +138,7 @@ void CMonthGraphicsview::setLunarVisible(bool visible)
  * @brief CMonthGraphicsview::setScheduleInfo 设置日程信息
  * @param info
  */
-void CMonthGraphicsview::setScheduleInfo(const QMap<QDate, QVector<ScheduleDataInfo>> &info)
+void CMonthGraphicsview::setScheduleInfo(const QMap<QDate, DSchedule::List> &info)
 {
     m_schedulelistdata = info;
     updateInfo();
@@ -148,7 +148,7 @@ void CMonthGraphicsview::setScheduleInfo(const QMap<QDate, QVector<ScheduleDataI
  * @brief CMonthGraphicsview::setSelectSearchSchedule     设置选择搜索日程
  * @param scheduleInfo
  */
-void CMonthGraphicsview::setSelectSearchSchedule(const ScheduleDataInfo &scheduleInfo)
+void CMonthGraphicsview::setSelectSearchSchedule(const DSchedule::Ptr &scheduleInfo)
 {
     DragInfoGraphicsView::setSelectSearchSchedule(scheduleInfo);
     //获取所有的日程item
@@ -171,7 +171,7 @@ void CMonthGraphicsview::setSelectSearchSchedule(const ScheduleDataInfo &schedul
  * @brief CMonthGraphicsview::setSearchScheduleInfo       设置搜索日程信息
  * @param searchScheduleInfo
  */
-void CMonthGraphicsview::setSearchScheduleInfo(const QVector<ScheduleDataInfo> &searchScheduleInfo)
+void CMonthGraphicsview::setSearchScheduleInfo(const DSchedule::List &searchScheduleInfo)
 {
     DragInfoItem::setSearchScheduleInfo(searchScheduleInfo);
     this->scene()->update();
@@ -211,7 +211,12 @@ void CMonthGraphicsview::updateLunar()
             info = m_lunarCache.value(date);
 
             if (info.mLunarDayName == "初一") {
-                info.mLunarDayName = info.mLunarMonthName + info.mLunarDayName;
+                //如果为闰月只显示月份不显示天
+                if (info.mLunarMonthName.contains("闰")) {
+                    info.mLunarDayName = info.mLunarMonthName;
+                } else {
+                    info.mLunarDayName = info.mLunarMonthName + info.mLunarDayName;
+                }
             }
 
             if (info.mTerm.isEmpty()) {
@@ -309,7 +314,7 @@ QDateTime CMonthGraphicsview::getPosDate(const QPoint &p)
                       QTime(0, 0, 0));
 }
 
-void CMonthGraphicsview::upDateInfoShow(const CMonthGraphicsview::DragStatus &status, const ScheduleDataInfo &info)
+void CMonthGraphicsview::upDateInfoShow(const CMonthGraphicsview::DragStatus &status, const DSchedule::Ptr &info)
 {
     switch (status) {
     case NONE:
@@ -383,8 +388,6 @@ void CMonthGraphicsview::mouseDoubleClickEvent(QMouseEvent *event)
     if (infoitem != nullptr) {
         CMyScheduleView dlg(infoitem->getData(), this);
         connect(&dlg, &CMyScheduleView::signalsEditorDelete, this, &CMonthGraphicsview::signalsUpdateSchedule);
-        connect(&dlg, &CMyScheduleView::signalViewtransparentFrame,
-                this, &CMonthGraphicsview::signalViewtransparentFrame);
         dlg.exec();
         return;
     }
@@ -400,7 +403,11 @@ void CMonthGraphicsview::mouseDoubleClickEvent(QMouseEvent *event)
             }
         } else {
             //双击新建日程
-            slotCreate(QDateTime(Dayitem->getDate(), QTime(0, 0, 0)));
+            if (Dayitem->getDate().year() >= DDECalendar::QueryEarliestYear) {
+                if (Dayitem->getDate().year() <= DDECalendar::QueryLatestYear) {
+                    slotCreate(QDateTime(Dayitem->getDate(), QTime(0, 0, 0)));
+                }
+            }
         }
     }
 }
@@ -455,7 +462,7 @@ void CMonthGraphicsview::setDragPixmap(QDrag *drag, DragInfoItem *item)
 
 bool CMonthGraphicsview::MeetCreationConditions(const QDateTime &date)
 {
-    return  qAbs(date.daysTo(m_PressDate) < 43);
+    return qAbs(date.daysTo(m_PressDate)) < 43;
 }
 
 bool CMonthGraphicsview::IsEqualtime(const QDateTime &timeFirst, const QDateTime &timeSecond)
@@ -481,11 +488,11 @@ void CMonthGraphicsview::RightClickToCreate(QGraphicsItem *listItem, const QPoin
     }
 }
 
-void CMonthGraphicsview::MoveInfoProcess(ScheduleDataInfo &info, const QPointF &pos)
+void CMonthGraphicsview::MoveInfoProcess(DSchedule::Ptr &info, const QPointF &pos)
 {
     qint64 offset       = m_PressDate.daysTo(m_MoveDate);
-    info.setBeginDateTime(info.getBeginDateTime().addDays(offset));
-    info.setEndDateTime(info.getEndDateTime().addDays(offset));
+    info->setDtStart(info->dtStart().addDays(offset));
+    info->setDtEnd(info->dtEnd().addDays(offset));
     qreal y = 0;
     QRectF rect = this->sceneRect();
 
@@ -535,7 +542,6 @@ QDateTime CMonthGraphicsview::getDragScheduleInfoEndTime(const QDateTime &moveDa
 
 void CMonthGraphicsview::slotCreate(const QDateTime &date)
 {
-    emit signalViewtransparentFrame(1);
     CScheduleDlg dlg(1, this);
     QDateTime tDatatime;
     tDatatime.setDate(date.date());
@@ -553,5 +559,4 @@ void CMonthGraphicsview::slotCreate(const QDateTime &date)
         emit signalsUpdateSchedule();
         emit signalsScheduleUpdate(0);
     }
-    emit signalViewtransparentFrame(0);
 }
