@@ -68,6 +68,7 @@
 #include <QColorDialog>
 #include <QApplication>
 #include <QWidgetAction>
+#include <QDesktopServices>
 
 #include <stdlib.h>
 #include <functional>
@@ -361,7 +362,6 @@ void Calendarmainwindow::initUI()
     setTabOrder(this->titlebar(), m_titleWidget);
     //设置状态栏焦点代理为标题窗口
     this->titlebar()->setFocusProxy(m_titleWidget);
-    //this->titlebar()->setFocusProxy(titleWidget);
 
     this->titlebar()->setQuitMenuVisible(true);//先设置后，才可以获取menu内容。因为setQuitMenuVisible接口中进行了action的添加操作
     QMenu *menuTitleBar = this->titlebar()->menu();
@@ -370,9 +370,14 @@ void Calendarmainwindow::initUI()
     //menuTitleBar->addAction(pSetting);
     menuTitleBar->insertSeparator(menuTitleBar->actions()[0]);
     menuTitleBar->insertAction(menuTitleBar->actions()[0], pSetting);
-
     connect(pSetting, &QAction::triggered, this, &Calendarmainwindow::slotOpenSettingDialog);
 
+    //添加隐私政策
+    QAction *pPrivacy = new QAction(tr("Privacy Policy"), menuTitleBar);
+    menuTitleBar->insertSeparator(menuTitleBar->actions()[1]);
+    menuTitleBar->insertAction(menuTitleBar->actions()[1], pPrivacy);
+    connect(pPrivacy, &QAction::triggered, this, &Calendarmainwindow::slotShowPrivacy);
+
     //接收设置按键焦点
     connect(m_titleWidget, &CTitleWidget::signalSetButtonFocus, [=] {
         m_setButtonFocus = true;
@@ -523,6 +528,27 @@ void Calendarmainwindow::createview()
 
 void Calendarmainwindow::resizeView()
 {
+    //帐户列表窗口（A），视图窗口(B),搜索结果窗口(C)
+    //窗口由大变小先隐藏A，在隐藏B
+    //窗口由小变大先显示B，在显示A
+    //不能出现只显示A和C的情况
+
+
+    //根据界面大小改变趋势设置侧边栏可显示状态
+    //如果帐户列表窗口为显示状态
+    if( m_titleWidget->getSidevarStatus()){
+        //如果显示搜索窗口，若需要显示帐户列表则界面的最小尺寸需要984，否则为826
+        int minWidth = m_opensearchflag ? 984 : 826 ;
+
+        if ( width() < minWidth) {
+            m_titleWidget->setSidebarCanDisplay(false);
+            m_sidebarView->setVisible(false);
+        } else if (width() > minWidth) {
+            m_titleWidget->setSidebarCanDisplay(true);
+            m_sidebarView->setVisible(true);
+        }
+    }
+
     m_transparentFrame->resize(width(), height() - 50);
 
     if (width() < CalendarSwitchWidth) {
@@ -535,7 +561,6 @@ void Calendarmainwindow::resizeView()
     if (!m_sidebarView->isHidden()) {
         sidWidth = m_sidebarView->width();
     }
-
     if (width() < CalendarViewSwitchWidth + sidWidth) {
         m_isNormalStateShow = false;
         m_stackWidget->setVisible(!m_contentBackground->isVisible());
@@ -569,16 +594,6 @@ void Calendarmainwindow::resizeEvent(QResizeEvent *event)
 {
     DMainWindow::resizeEvent(event);
 
-    static int preWidth = 0;    //上一次界面宽度
-    //根据界面大小改变趋势设置侧边栏可显示状态
-    if ((preWidth >= 826 || preWidth == 0) && width() < 826) {
-        m_titleWidget->setSidebarCanDisplay(false);
-    } else if ((preWidth <= 826) && width() > 826) {
-        m_titleWidget->setSidebarCanDisplay(true);
-    }
-
-    preWidth = width();
-
     resizeView();
 
     //保存窗口大小
@@ -612,15 +627,11 @@ void Calendarmainwindow::slotSreturnPressed()
         m_opensearchflag = true;
     }
     //如果为搜索状态
-    if (m_opensearchflag) {
-        //根据显示显示状态，是否显示左侧视图窗口
-        if (!m_isNormalStateShow) {
-            m_stackWidget->setVisible(false);
-        }
-        m_contentBackground->setVisible(true);
-    }
+    m_contentBackground->setVisible(m_opensearchflag);
+
     m_scheduleSearchView->slotsetSearch(m_searchEdit->text());
     updateHeight();
+    resizeView();
 }
 
 void Calendarmainwindow::slotStextChanged()
@@ -639,6 +650,7 @@ void Calendarmainwindow::slotStextChanged()
         m_contentBackground->setVisible(false);
         m_stackWidget->setVisible(true);
         m_opensearchflag = false;
+        resizeView();
     }
     updateHeight();
 }
@@ -668,8 +680,6 @@ void Calendarmainwindow::slotSearchSelectSchedule(const DSchedule::Ptr &schedule
     //如果小尺寸显示模式，在显示搜索窗口的时候，左侧视图会被隐藏
     //如果点击一个搜索结果则隐藏搜索窗口，展示左侧视图
     if (!m_isNormalStateShow) {
-        //        CalendarGlobalEnv::getGlobalEnv()->registerKey("SearchItemEvent", "Keyboard");
-
         QVariant variant;
         CalendarGlobalEnv::getGlobalEnv()->getValueByKey("SearchItemEvent", variant);
         QString searchItemEvent = variant.toString();
@@ -686,14 +696,14 @@ void Calendarmainwindow::slotSearchSelectSchedule(const DSchedule::Ptr &schedule
         bool changeYear = _showWidget->getSelectDate().year() != scheduleInfo->dtStart().date().year();
         //设置选择时间
         if (_showWidget->setSelectDate(scheduleInfo->dtStart().date(), changeYear)) {
-            //更新显示数据
-            _showWidget->updateData();
-            //设置年份信息显示
-            _showWidget->setYearData();
-            //延迟150毫秒设置选中动画
-            QTimer::singleShot(150, this, [ = ] {
-                _showWidget->setSelectSearchScheduleInfo(scheduleInfo);
-            });
+           //更新显示数据
+           _showWidget->updateData();
+           //设置年份信息显示
+           _showWidget->setYearData();
+           //延迟150毫秒设置选中动画
+           QTimer::singleShot(150, this, [ = ] {
+               _showWidget->setSelectSearchScheduleInfo(scheduleInfo);
+           });
         }
         //如果当前界面不为年试图则更新年视图数据
         if (_showWidget != m_yearwindow) {
@@ -815,13 +825,14 @@ void Calendarmainwindow::slotSearchFocusSwitch()
 
 void Calendarmainwindow::slotSidebarStatusChange(bool status)
 {
-    //设置帐户侧边栏显示状态
+    //先显示再调整窗口大小
     m_sidebarView->setVisible(status);
-    //展开侧边栏后最小宽度为826
-    if (status && width() < 826) {
-        resize(826, height());
-    } else {
-        resizeView(); //刷新界面
+    if(status){
+        //如果显示搜索窗口，若需要显示帐户列表则界面的最小尺寸需要984，否则为826
+        int minWidth = m_opensearchflag ? 984 : 826 ;
+        if (width() < minWidth){
+            resize(minWidth,height());
+        }
     }
 }
 
@@ -898,6 +909,28 @@ void Calendarmainwindow::slotOpenSettingDialog()
     gCalendarManager->updateData();
 }
 
+void Calendarmainwindow::slotShowPrivacy()
+{
+    QString url = "";
+    QLocale locale;
+    QLocale::Country country = locale.country();
+    bool isCommunityEdition = DSysInfo::isCommunityEdition();
+    if (country == QLocale::China) {
+        if (isCommunityEdition) {
+            url = "https://www.deepin.org/zh/agreement/privacy/";
+        } else {
+            url = "https://www.uniontech.com/agreement/privacy-cn";
+        }
+    } else {
+        if (isCommunityEdition) {
+            url = "https://www.deepin.org/en/agreement/privacy/";
+        } else {
+            url = "https://www.uniontech.com/agreement/privacy-en";
+        }
+    }
+    QDesktopServices::openUrl(url);
+}
+
 void Calendarmainwindow::slotShowSyncToast(int syncNum)
 {
     //-1:正在刷新 0:正常 1:网络异常 2:服务器异常 3：存储已经满
