@@ -228,6 +228,7 @@ void DUIDSynDataWorker::startUpdate()
     if (errCode == 0 && mSync.syncType.testFlag(DDataSyncBase::SyncType::Sync_Download)) {
         errCode =  mSync.tmpToLoad(updateType);
     }
+
     if (errCode == 0) {
         transactionLocker.commit();
     } else {
@@ -289,6 +290,7 @@ int SyncStack::downloadUidData(bool &isInitSyncData, SyncFileManage &fileManger)
         return -1;
     }
     qInfo() << "初始化表结构";
+
     SqliteQuery query(dbname_sync_thread);
 
     if (!query.exec(DAccountDataBase::sql_create_schedules))
@@ -325,8 +327,10 @@ int SyncStack::downloadUidData(bool &isInitSyncData, SyncFileManage &fileManger)
 
         if (accountState & DAccount::Account_Setting) {
             qInfo() << "默认通用设置";
-            if (!syncIntoTable("calendargeneralsettings", dbname_manager_thread, dbname_sync_thread))
-                return -1;
+            if(needUpdateSettingValue()) {
+                if (!syncIntoTable("calendargeneralsettings", dbname_manager_thread, dbname_sync_thread))
+                    return -1;
+            }
         }
         //云端没有对应数据需要初始化，返回初始化状态
         isInitSyncData = true;
@@ -338,62 +342,107 @@ int SyncStack::downloadUidData(bool &isInitSyncData, SyncFileManage &fileManger)
 int SyncStack::loadToTmp()
 {
     qInfo() << "将本地A的uploadTask同步到刚刚下载的B里";
-    SqliteQuery query(dbname_account_thread);
-    query.exec("select taskID,uploadType,uploadObject,objectID  from uploadTask");
-    while (query.next()) {
-        int type = query.value("uploadType").toInt();
-        int obj = query.value("uploadObject").toInt();
-        QString key_value = query.value("objectID").toString();
-        QString key_name = DUploadTaskData::sql_table_primary_key(obj);
-        QString table_name = DUploadTaskData::sql_table_name(obj);
+    if(accountState & DAccount::Account_Calendar) {
+        SqliteQuery query(dbname_account_thread);
+        query.exec("select taskID,uploadType,uploadObject,objectID  from uploadTask");
+        while (query.next()) {
+            int type = query.value("uploadType").toInt();
+            int obj = query.value("uploadObject").toInt();
+            QString key_value = query.value("objectID").toString();
+            QString key_name = DUploadTaskData::sql_table_primary_key(obj);
+            QString table_name = DUploadTaskData::sql_table_name(obj);
 
-        switch (type) {
-        case DUploadTaskData::Create:
-        case DUploadTaskData::Modify:
-            if (!replaceIntoRecord(table_name, selectRecord(table_name, key_name, key_value, dbname_account_thread), dbname_sync_thread))
-                return -1;
-            break;
-        case DUploadTaskData::Delete:
-            if (!deleteTableLine(table_name, key_name, key_value, dbname_sync_thread))
-                return -1;
-            break;
+            switch (type) {
+            case DUploadTaskData::Create:
+            case DUploadTaskData::Modify:
+                if (!replaceIntoRecord(table_name, selectRecord(table_name, key_name, key_value, dbname_account_thread), dbname_sync_thread)){
+                    qWarning()<<"faild:" <<__FUNCTION__ <<" : "<<__LINE__;
+                    return -1;
+                }
+                break;
+            case DUploadTaskData::Delete:
+                if (!deleteTableLine(table_name, key_name, key_value, dbname_sync_thread)){
+                    qWarning()<<"faild:" <<__FUNCTION__ <<" : "<<__LINE__;
+                    return -1;
+                }
+                break;
+            }
+        }
+
+        qInfo() << "清空uploadTask";
+        if (!deleteTable("uploadTask", dbname_account_thread)){
+            qWarning()<<"faild:" <<__FUNCTION__ <<" : "<<__LINE__;
+            return -1;
         }
     }
 
-    qInfo() << "清空uploadTask";
-    if (!deleteTable("uploadTask", dbname_account_thread))
-        return -1;
-
     if (accountState & DAccount::Account_Setting) {
+
         qInfo() << "同步通用设置";
-        QDateTime managerDate = selectValue("vch_value", "calendargeneralsettings", "vch_key", "dt_update", dbname_manager_thread).toDateTime();
-        QDateTime syncDate = selectValue("vch_value", "calendargeneralsettings", "vch_key", "dt_update", dbname_sync_thread).toDateTime();
-        if (managerDate > syncDate)
-            if (!syncIntoTable("calendargeneralsettings", dbname_manager_thread, dbname_sync_thread))
-                return -1;
-        if (syncDate > managerDate)
-            if (!syncIntoTable("calendargeneralsettings", dbname_sync_thread, dbname_manager_thread))
-                return -1;
+        if(needUpdateSettingValue()) {
+            QDateTime managerDate = selectValue("vch_value", "calendargeneralsettings", "vch_key", "dt_update", dbname_manager_thread).toDateTime();
+            QDateTime syncDate = selectValue("vch_value", "calendargeneralsettings", "vch_key", "dt_update", dbname_sync_thread).toDateTime();
+            if (managerDate > syncDate)
+                if (!syncIntoTable("calendargeneralsettings", dbname_manager_thread, dbname_sync_thread)){
+                    qWarning()<<"faild:" <<__FUNCTION__ <<" : "<<__LINE__;
+                    return -1;
+                }
+            if (syncDate > managerDate)
+                if (!syncIntoTable("calendargeneralsettings", dbname_sync_thread, dbname_manager_thread)){
+                    qWarning()<<"faild:" <<__FUNCTION__ <<" : "<<__LINE__;
+                    return -1;
+                }
+        }
     }
 
+
     return 0;
 }
 
+bool SyncStack::needUpdateSettingValue() {
+    int mangerdayweek = selectValue("vch_value", "calendargeneralsettings", "vch_key", "firstDayOfWeek", dbname_manager_thread).toInt();
+    int syncdayweek = selectValue("vch_value", "calendargeneralsettings", "vch_key", "firstDayOfWeek", dbname_sync_thread).toInt();
+    if(mangerdayweek != syncdayweek) {
+        return  true;
+    }
+
+    int mangerTimeShow = selectValue("vch_value", "calendargeneralsettings", "vch_key", "timeShowType", dbname_manager_thread).toInt();
+    int syncTimeShow = selectValue("vch_value", "calendargeneralsettings", "vch_key", "timeShowType", dbname_sync_thread).toInt();
+    if(mangerTimeShow != syncTimeShow) {
+        return  true;
+    }
+
+    return false;
+}
+
 int SyncStack::tmpToLoad(DDataSyncBase::UpdateTypes &updateType)
 {
-    qInfo() << "更新schedules、schedules、typeColor";
-    if (!syncIntoTable("schedules", dbname_sync_thread, dbname_account_thread))
-        return -1;
-    if (!syncIntoTable("scheduleType", dbname_sync_thread, dbname_account_thread))
-        return -1;
-    if (!syncIntoTable("typeColor", dbname_sync_thread, dbname_account_thread))
-        return -1;
-    updateType = DUnionIDDav::Update_Schedule | DUnionIDDav::Update_ScheduleType;
+    if (accountState & DAccount::Account_Calendar) {
+        qInfo() << "更新schedules、schedules、typeColor";
+        if (!syncIntoTable("schedules", dbname_sync_thread, dbname_account_thread)){
+            qWarning()<<"faild:" <<__FUNCTION__ <<" : "<<__LINE__;
+            return -1;
+        }
+        if (!syncIntoTable("scheduleType", dbname_sync_thread, dbname_account_thread)){
+            qWarning()<<"faild:" <<__FUNCTION__ <<" : "<<__LINE__;
+            return -1;
+        }
+        if (!syncIntoTable("typeColor", dbname_sync_thread, dbname_account_thread)){
+            qWarning()<<"faild:" <<__FUNCTION__ <<" : "<<__LINE__;
+            return -1;
+        }
+        updateType = DUnionIDDav::Update_Schedule | DUnionIDDav::Update_ScheduleType;
+    }
 
     if (accountState & DAccount::Account_Setting) {
         qInfo() << "更新通用设置";
-        if (!syncIntoTable("calendargeneralsettings", dbname_sync_thread, dbname_manager_thread))
-            return -1;
+        if(needUpdateSettingValue()) {
+            if (!syncIntoTable("calendargeneralsettings", dbname_sync_thread, dbname_manager_thread)){
+                qWarning()<<"faild:" <<__FUNCTION__ <<" : "<<__LINE__;
+                return -1;
+            }
+        }
+
         updateType = updateType | DUnionIDDav::Update_Setting;
     }
 
@@ -432,8 +481,10 @@ bool SyncStack::syncIntoTable(const QString &table_name, const QString &connecti
 {
     SqliteQuery source(QSqlDatabase::database(connection_name_source));
     SqliteQuery target(QSqlDatabase::database(connection_name_target));
-    if (!target.exec(" delete from " + table_name))
+    if (!target.exec(" delete from " + table_name)){
+        qWarning() << target.lastError() <<"table_name:"<<table_name;
         return false;
+    }
     source.exec(" select * from " + table_name);
     while (source.next()) {
         target.prepare("replace into " + table_name + " values(" + prepareQuest(source.record().count()) + ")");
